@@ -7,7 +7,6 @@ from commodplot import commodplotutil as cpu
 
 
 class TestCommodPlotUtil(unittest.TestCase):
-
     def test_delta_summary_str(self):
         df = cf.datagen.lines(2, 1000)
         col = df.columns[0]
@@ -21,19 +20,19 @@ class TestCommodPlotUtil(unittest.TestCase):
         self.assertIn(str(diff.round(2)), res)
 
     def test_gen_title(self):
-        df = pd.DataFrame([1, 2, 3], columns=['Test'])
+        df = pd.DataFrame([1, 2, 3], columns=["Test"])
 
         res = cpu.gen_title(df, title=None)
-        self.assertTrue(res.startswith('3'))
+        self.assertTrue(res.startswith("3"))
 
-        res = cpu.gen_title(df, title='TTitle')
-        self.assertTrue(res.startswith('TTitle'))
-        self.assertTrue(res.endswith('+1'))
+        res = cpu.gen_title(df, title="TTitle")
+        self.assertTrue(res.startswith("TTitle"))
+        self.assertTrue(res.endswith("+1"))
 
-        res = cpu.gen_title(df, title='TTitle', title_postfix='post')
-        self.assertTrue(res.startswith('TTitle  post:'))
-        self.assertTrue(res.endswith('+1'))
+        res = cpu.gen_title(df, title="TTitle", title_postfix="post")
+        self.assertTrue(res.startswith("TTitle  post:"))
+        self.assertTrue(res.endswith("+1"))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
